import { Link } from "wouter";

interface Category {
  name: string;
  slug: string;
  image: string;
  count: number;
}

interface CategoryGridProps {
  categories: Category[];
  title?: string;
}

const CategoryGrid = ({ categories, title = "Découvrez la Guadeloupe" }: CategoryGridProps) => {
  return (
    <section className="mb-10">
      <h2 className="text-2xl font-bold mb-6 text-teal-800">{title}</h2>
      
      <div className="grid grid-cols-2 md:grid-cols-4 gap-4">
        {categories.map((category) => (
          <Link key={category.slug} href={`/categories/${category.slug}`}>
            <div className="relative rounded-lg overflow-hidden h-40 group cursor-pointer border-2 border-teal-200 shadow-md">
              <img 
                src={category.image} 
                alt={category.name} 
                className="w-full h-full object-cover transition-transform duration-300 group-hover:scale-110"
              />
              <div className="absolute inset-0 bg-gradient-to-t from-teal-900/80 to-transparent group-hover:from-teal-800/70"></div>
              <div className="absolute bottom-0 left-0 p-4 text-white">
                <h3 className="font-bold">{category.name}</h3>
                <p className="text-sm"><span className="text-yellow-300">{category.count}</span> annonces</p>
              </div>
            </div>
          </Link>
        ))}
      </div>
    </section>
  );
};

export default CategoryGrid;
